==> moniwiki-1.1.1.tgz: moniwiki/theme/blue/footer.php <==
</td>
<?php
# enable/disable sidebar
$_theme['sidebar']=1;

if ($_theme['sidebar']==1) :
?>
<td bgcolor='#fafafa'>
<div id='wikiSideMenu'>
<?php
print macro_login($this);
print '<div style="font-size:11px;font-family:verdana,sans-serif">';
if ($options['id']=='Anonymous')
  print macro_calendar($this,"'Blog',blog,noweek,archive",'Blog');
else
  print macro_calendar($this,"'$options[id]',blog,noweek,archive",$options['id']);
print '</div>';
print '<font style="font-size:12px;"><b>';
print macro_RandomQuote($this);
print '</b></font>';
print "<br /><br />\n";
print '<font style="font-size:11px">';
print macro_RandomPage($this,"4,simple");
print '</font>';
?>
</div>
</td>
<?php
endif;

$banner= <<<FOOT
 <a href="http://validator.w3.org/check/referer"><img
  src="$this->themeurl/imgs/xhtml.png"
  border="0" width="80" height="15"
  align="middle"
  alt="Valid XHTML 1.0!" /></a>

 <a href="http://jigsaw.w3.org/css-validator/check/referer"><img
  src="$this->themeurl/imgs/css.png"
  border="0" width="80" height="15"
  align="middle"
  alt="Valid CSS!" /></a>

 <a href="http://moniwiki.sourceforge.net/"><img
  src="$this->themeurl/imgs/moniwiki-powered-thin.png"
  border="0" width="80" height="15"
  align="middle"
  alt="powered by MoniWiki" /></a>
FOOT;
?>

</tr></table>
<div id='wikiFooter'>
<?php
  print $menu.'<br/>';
  print '<div id="wikiBanner">'.$banner.'<br />';
  if ($lastedit)
    print "last modified $lastedit $lasttime<br />";
  print 'Processing time '.$timer;
  print '</div>';
?>
</div>

</div></div></div></div></div></div>
</div></div>

==> moniwiki-1.1.2.tgz: moniwiki/theme/blue/footer.php <==
</td>
<?php
# enable/disable sidebar
if ($this->_sidebar==1) :
?>
<td bgcolor='#fafafa'>
<div id='wikiSideMenu'>
<?php
print macro_login($this);
print '<div class="calendar">';
if ($options['id']=='Anonymous')
  print macro_calendar($this,"'Blog',blog,noweek,archive,center",'Blog');
else
  print macro_calendar($this,"'$options[id]',center,blog,noweek,archive",$options['id']);
print '</div>';
print '<div class="randomQuote">';
print macro_RandomQuote($this);
print '</div>';
print '<div class="randomPage">';
print macro_RandomPage($this,"4,simple");
print '</div>';
if ($DBInfo->use_tagging) {
  print "<div>";
  print macro_Keywords($this,"all,tour,limit=15");
  print "</div>";
}
?>
</div>
</td>
<?php
endif;

$banner= <<<FOOT
 <a href="http://validator.w3.org/check/referer"><img
  src="$this->themeurl/imgs/xhtml.png"
  border="0" width="80" height="15"
  align="middle"
  alt="Valid XHTML 1.0!" /></a>

 <a href="http://jigsaw.w3.org/css-validator/check/referer"><img
  src="$this->themeurl/imgs/css.png"
  border="0" width="80" height="15"
  align="middle"
  alt="Valid CSS!" /></a>

 <a href="http://moniwiki.sourceforge.net/"><img
  src="$this->themeurl/imgs/moniwiki-powered-thin.png"
  border="0" width="80" height="15"
  align="middle"
  alt="powered by MoniWiki" /></a>
FOOT;
?>

</tr></table>
<div id='wikiFooter'>
<?php
  print $menu.'<br/>';
  print '<div id="wikiBanner">'.$banner.'<br />';
  if ($lastedit)
    print "last modified $lastedit $lasttime<br />";
  print 'Processing time '.$timer;
  print '</div>';
?>
</div>

</div></div></div></div></div></div>
</div></div>
